@@ -29,7 +29,7 @@ module Diagrams.Attributes (
     Color(..), SomeColor(..)
 
   -- ** Line color
-  , LineColor, getLineColor, lineColor, lc, lcA
+  , LineColor, getLineColor, lineColor, lineColorA, lc, lcA
 
   -- ** Fill color
   , FillColor, getFillColor, recommendFillColor, fillColor, fc, fcA
@@ -37,9 +37,12 @@ module Diagrams.Attributes (
   -- ** Opacity
   , Opacity, getOpacity, opacity
 
+  -- ** Converting colors
+  , toRGBAUsingSpace, colorToSRGBA, colorToRGBA
+
   -- * Lines
   -- ** Width
-  , LineWidth, getLineWidth, lineWidth, lw
+  , LineWidth, getLineWidth, lineWidth, lineWidthA, lw
 
   -- ** Cap style
   , LineCap(..), LineCapA, getLineCap, lineCap
@@ -47,6 +50,9 @@ module Diagrams.Attributes (
   -- ** Join style
   , LineJoin(..), LineJoinA, getLineJoin, lineJoin
 
+  -- ** Miter limit
+  , LineMiterLimit(..), getLineMiterLimit, lineMiterLimit, lineMiterLimitA
+
   -- ** Dashing
   , Dashing(..), DashingA, getDashing, dashing
 
@@ -54,8 +60,11 @@ module Diagrams.Attributes (
 
 import           Diagrams.Core
 
+import           Data.Default.Class
+
 import           Data.Colour
-import qualified Data.Colour.SRGB as RGB
+import           Data.Colour.RGBSpace
+import           Data.Colour.SRGB (sRGBSpace)
 
 import           Data.Typeable
 
@@ -79,9 +88,8 @@ import           Data.Semigroup
 --   both the 'Data.Colour.Colour' and 'Data.Colour.AlphaColour' types
 --   from the "Data.Colour" library.
 class Color c where
-  -- | Convert a color to red, green, blue, and alpha channels in the
-  --   range [0,1].
-  colorToRGBA :: c -> (Double,Double,Double,Double)
+  -- | Convert a color to its standard representation, AlphaColour
+  toAlphaColour :: c -> AlphaColour Double
 
 -- | An existential wrapper for instances of the 'Color' class.
 data SomeColor = forall c. Color c => SomeColor c
@@ -96,6 +104,9 @@ newtype LineColor = LineColor (Last SomeColor)
   deriving (Typeable, Semigroup)
 instance AttributeClass LineColor
 
+instance Default LineColor where
+    def = LineColor (Last (SomeColor black))
+
 getLineColor :: LineColor -> SomeColor
 getLineColor (LineColor (Last c)) = c
 
@@ -107,6 +118,10 @@ getLineColor (LineColor (Last c)) = c
 lineColor :: (Color c, HasStyle a) => c -> a -> a
 lineColor = applyAttr . LineColor . Last . SomeColor
 
+-- | Apply a 'lineColor' attribute.
+lineColorA :: HasStyle a => LineColor -> a -> a
+lineColorA = applyAttr
+
 -- | A synonym for 'lineColor', specialized to @'Colour' Double@
 --   (i.e. opaque colors).
 lc :: HasStyle a => Colour Double -> a -> a
@@ -152,29 +167,37 @@ fcA :: HasStyle a => AlphaColour Double -> a -> a
 fcA = fillColor
 
 instance (Floating a, Real a) => Color (Colour a) where
-  colorToRGBA col = (r,g,b,1)
-    where c' = RGB.toSRGB . colourConvert $ col
-          r  = RGB.channelRed c'
-          g  = RGB.channelGreen c'
-          b  = RGB.channelBlue c'
+  toAlphaColour = opaque . colourConvert
 
 instance (Floating a, Real a) => Color (AlphaColour a) where
-  colorToRGBA col = (r,g,b,a)
-    where col' = alphaColourConvert col
-          a  = alphaChannel col'
-          c' = RGB.toSRGB . alphaToColour $ col'
-          r  = RGB.channelRed c'
-          g  = RGB.channelGreen c'
-          b  = RGB.channelBlue c'
+  toAlphaColour = alphaColourConvert
 
 instance Color SomeColor where
-  colorToRGBA (SomeColor c) = colorToRGBA c
+  toAlphaColour (SomeColor c) = toAlphaColour c
 
 instance Color LineColor where
-  colorToRGBA (LineColor (Last c)) = colorToRGBA c
+  toAlphaColour (LineColor (Last c)) = toAlphaColour c
 
 instance Color FillColor where
-  colorToRGBA (FillColor c) = colorToRGBA . getLast . getRecommend $ c
+  toAlphaColour (FillColor c) = toAlphaColour . getLast . getRecommend $ c
+
+-- | Convert to an RGB space while preserving the alpha channel.
+toRGBAUsingSpace :: Color c => RGBSpace Double -> c
+                            -> (Double, Double, Double, Double)
+toRGBAUsingSpace s col = (r,g,b,a)
+  where c' = toAlphaColour col
+        c  = toRGBUsingSpace s (alphaToColour c')
+        a  = alphaChannel  c'
+        r  = channelRed   c
+        g  = channelGreen c
+        b  = channelBlue  c
+
+-- | Convert to sRGBA.
+colorToSRGBA, colorToRGBA :: Color c => c -> (Double, Double, Double, Double)
+colorToSRGBA = toRGBAUsingSpace sRGBSpace
+
+colorToRGBA = colorToSRGBA
+{-# DEPRECATED colorToRGBA "Renamed to colorToSRGBA." #-}
 
 alphaToColour :: (Floating a, Ord a, Fractional a) => AlphaColour a -> Colour a
 alphaToColour ac | alphaChannel ac == 0 = ac `over` black
@@ -224,6 +247,9 @@ newtype LineWidth = LineWidth (Last Double)
   deriving (Typeable, Semigroup)
 instance AttributeClass LineWidth
 
+instance Default LineWidth where
+    def = LineWidth (Last 0.01)
+
 getLineWidth :: LineWidth -> Double
 getLineWidth (LineWidth (Last w)) = w
 
@@ -231,6 +257,10 @@ getLineWidth (LineWidth (Last w)) = w
 lineWidth :: HasStyle a => Double -> a -> a
 lineWidth = applyAttr . LineWidth . Last
 
+-- | Apply a 'LineWidth' attribute.
+lineWidthA ::  HasStyle a => LineWidth -> a -> a
+lineWidthA = applyAttr
+
 -- | A convenient synonym for 'lineWidth'.
 lw :: HasStyle a => Double -> a -> a
 lw = lineWidth
@@ -247,6 +277,9 @@ newtype LineCapA = LineCapA (Last LineCap)
   deriving (Typeable, Semigroup, Eq)
 instance AttributeClass LineCapA
 
+instance Default LineCap where
+    def = LineCapButt
+
 getLineCap :: LineCapA -> LineCap
 getLineCap (LineCapA (Last c)) = c
 
@@ -267,6 +300,9 @@ newtype LineJoinA = LineJoinA (Last LineJoin)
   deriving (Typeable, Semigroup, Eq)
 instance AttributeClass LineJoinA
 
+instance Default LineJoin where
+    def = LineJoinMiter
+
 getLineJoin :: LineJoinA -> LineJoin
 getLineJoin (LineJoinA (Last j)) = j
 
@@ -274,6 +310,27 @@ getLineJoin (LineJoinA (Last j)) = j
 lineJoin :: HasStyle a => LineJoin -> a -> a
 lineJoin = applyAttr . LineJoinA . Last
 
+
+-- | Miter limit attribute affecting the 'LineJoinMiter' joins.
+--   For some backends this value may have additional effects.
+newtype LineMiterLimit = LineMiterLimit (Last Double)
+  deriving (Typeable, Semigroup)
+instance AttributeClass LineMiterLimit
+
+instance Default LineMiterLimit where
+    def = LineMiterLimit (Last 10)
+
+getLineMiterLimit :: LineMiterLimit -> Double
+getLineMiterLimit (LineMiterLimit (Last l)) = l
+
+-- | Set the miter limit for joins with 'LineJoinMiter'.
+lineMiterLimit :: HasStyle a => Double -> a -> a
+lineMiterLimit = applyAttr . LineMiterLimit . Last
+
+-- | Apply a 'LineMiterLimit' attribute.
+lineMiterLimitA :: HasStyle a => LineMiterLimit -> a -> a
+lineMiterLimitA = applyAttr
+
 -- | Create lines that are dashing... er, dashed.
 data Dashing = Dashing [Double] Double
   deriving (Typeable, Eq)
