@@ -1,5 +1,5 @@
-{-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE TypeFamilies     #-}
 
 -----------------------------------------------------------------------------
 -- |
@@ -8,23 +8,28 @@
 -- License     :  BSD-style (see LICENSE)
 -- Maintainer  :  diagrams-discuss@googlegroups.com
 --
--- Some miscellaneous utilities for working with points.
+-- Points in space.  For more tools for working with points and
+-- vectors, see "Data.AffineSpace" and "Diagrams.Coordinates".
 --
 -----------------------------------------------------------------------------
 
 module Diagrams.Points
-       ( centroid
+       ( -- * Points
+         Point, origin, (*.)
+
+         -- * Point-related utilities
+       , centroid
 
        ) where
 
-import Diagrams.Coordinates
-import Diagrams.Core.Points
+import           Diagrams.Coordinates
+import           Diagrams.Core.Points
 
-import Control.Newtype
+import           Control.Newtype
 
-import Control.Arrow ((&&&))
+import           Control.Arrow        ((&&&))
 
-import Data.VectorSpace
+import           Data.VectorSpace
 
 -- | The centroid of a set of /n/ points is their sum divided by /n/.
 centroid :: (VectorSpace v, Fractional (Scalar v)) => [Point v] -> Point v
