@@ -24,7 +24,7 @@ import Prelude hiding (minimum)
 import Data.Semigroup
 
 import Data.AffineSpace
-import Data.Monoid.PosInf (minimum)
+import Data.Monoid.Inf (minimum)
 import Data.VectorSpace
 
 import Diagrams.Core
@@ -39,6 +39,8 @@ type instance V Ellipsoid = R3
 instance Transformable Ellipsoid where
   transform t1 (Ellipsoid t2) = Ellipsoid (t1 <> t2)
 
+instance IsPrim Ellipsoid
+
 instance Renderable Ellipsoid NullBackend where
   render _ _ = mempty
 
