@@ -1,4 +1,6 @@
-{-# LANGUAGE TypeSynonymInstances, FlexibleContexts, TypeFamilies #-}
+{-# LANGUAGE FlexibleContexts     #-}
+{-# LANGUAGE TypeFamilies         #-}
+{-# LANGUAGE TypeSynonymInstances #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Diagrams.TwoD
@@ -65,12 +67,13 @@ module Diagrams.TwoD
          -- * Angles
        , tau
        , Angle(..)
-       , CircleFrac(..), Rad(..), Deg(..)
+       , Turn(..), CircleFrac, Rad(..), Deg(..)
        , fullCircle, convertAngle
 
          -- * Paths
          -- ** Stroking
-       , stroke, stroke', strokeT, strokeT'
+       , stroke, stroke', strokeT, strokeT', strokeLine, strokeLoop
+       , strokeLocT, strokeLocLine, strokeLocLoop
        , FillRule(..), fillRule
        , StrokeOpts(..)
 
@@ -92,7 +95,7 @@ module Diagrams.TwoD
        , wedge
 
          -- ** General polygons
-       , polygon, polyVertices
+       , polygon, polyTrail
        , PolygonOpts(..), PolyType(..), PolyOrientation(..)
 
          -- ** Star polygons
@@ -100,6 +103,7 @@ module Diagrams.TwoD
 
          -- ** Regular polygons
        , regPoly
+       , triangle
        , eqTriangle
        , square
        , pentagon
@@ -191,19 +195,19 @@ module Diagrams.TwoD
 
        ) where
 
-import Diagrams.TwoD.Types
-import Diagrams.TwoD.Path
-import Diagrams.TwoD.Ellipse
-import Diagrams.TwoD.Arc
-import Diagrams.TwoD.Polygons
-import Diagrams.TwoD.Shapes
-import Diagrams.TwoD.Transform
-import Diagrams.TwoD.Align
-import Diagrams.TwoD.Combinators
-import Diagrams.TwoD.Vector
-import Diagrams.TwoD.Size
-import Diagrams.TwoD.Model
-import Diagrams.TwoD.Text
-import Diagrams.TwoD.Image
+import           Diagrams.TwoD.Align
+import           Diagrams.TwoD.Arc
+import           Diagrams.TwoD.Combinators
+import           Diagrams.TwoD.Ellipse
+import           Diagrams.TwoD.Image
+import           Diagrams.TwoD.Model
+import           Diagrams.TwoD.Path
+import           Diagrams.TwoD.Polygons
+import           Diagrams.TwoD.Shapes
+import           Diagrams.TwoD.Size
+import           Diagrams.TwoD.Text
+import           Diagrams.TwoD.Transform
+import           Diagrams.TwoD.Types
+import           Diagrams.TwoD.Vector
 
-import Diagrams.Util (tau)
\ No newline at end of file
+import           Diagrams.Util             (tau)
