@@ -1,7 +1,7 @@
-{-# LANGUAGE FlexibleContexts
-           , TypeFamilies
-           , ViewPatterns
-  #-}
+{-# LANGUAGE FlexibleContexts      #-}
+{-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE TypeFamilies          #-}
+{-# LANGUAGE ViewPatterns          #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Diagrams.TwoD.Combinators
@@ -37,54 +37,57 @@ module Diagrams.TwoD.Combinators
 
     ) where
 
-import Data.AffineSpace
-import Data.Colour
-import Data.Default
-import Data.Semigroup
-import Data.VectorSpace
+import           Data.AffineSpace
+import           Data.Colour
+import           Data.Default.Class
+import           Data.Semigroup
+import           Data.VectorSpace
 
-import Diagrams.Core
+import           Diagrams.Core
 
-import Diagrams.Attributes (lw, fc)
-import Diagrams.BoundingBox
-import Diagrams.Combinators
-import Diagrams.Coordinates
-import Diagrams.Path
-import Diagrams.Segment
-import Diagrams.TwoD.Align
-import Diagrams.TwoD.Path ()   -- for PathLike (D R2) instance
-import Diagrams.TwoD.Segment
-import Diagrams.TwoD.Shapes
-import Diagrams.TwoD.Transform (scaleX, scaleY)
-import Diagrams.TwoD.Types
-import Diagrams.TwoD.Vector (unitX, unitY, fromDirection)
-import Diagrams.Util ((#))
+import           Diagrams.Attributes     (fc, lw)
+import           Diagrams.BoundingBox
+import           Diagrams.Combinators
+import           Diagrams.Coordinates
+import           Diagrams.Path
+import           Diagrams.Segment
+import           Diagrams.TrailLike
+import           Diagrams.TwoD.Align
+import           Diagrams.TwoD.Path      ()
+import           Diagrams.TwoD.Segment
+import           Diagrams.TwoD.Shapes
+import           Diagrams.TwoD.Transform (scaleX, scaleY)
+import           Diagrams.TwoD.Types
+import           Diagrams.TwoD.Vector    (fromDirection, unitX, unitY)
+import           Diagrams.Util           (( # ))
 
 
 infixl 6 ===
 infixl 6 |||
 
--- | Place two diagrams (or other objects) vertically
---   adjacent to one another, with the first diagram above the second.
---   Since Haskell ignores whitespace in expressions, one can thus write
+-- | Place two diagrams (or other objects) vertically adjacent to one
+--   another, with the first diagram above the second.  Since Haskell
+--   ignores whitespace in expressions, one can thus write
 --
---   >    c
---   >   ===
---   >    d
+--   @
+--       c
+--      ===
+--       d
+--   @
 --
 --   to place @c@ above @d@.  The local origin of the resulting
 --   combined diagram is the same as the local origin of the first.
---   @(===)@ is associative and has 'mempty' as a right (but not left)
---   identity.  See the documentation of 'beside' for more information.
+--   @(===)@ is associative and has 'mempty' as an identity.  See the
+--   documentation of 'beside' for more information.
 (===) :: (Juxtaposable a, V a ~ R2, Semigroup a) => a -> a -> a
 (===) = beside (negateV unitY)
 
 -- | Place two diagrams (or other juxtaposable objects) horizontally
 --   adjacent to one another, with the first diagram to the left of
---   the second.  The local origin of the resulting
---   combined diagram is the same as the local origin of the first.
---   @(===)@ is associative and has 'mempty' as a right (but not left)
---   identity.  See the documentation of 'beside' for more information.
+--   the second.  The local origin of the resulting combined diagram
+--   is the same as the local origin of the first.  @(===)@ is
+--   associative and has 'mempty' as an identity.  See the
+--   documentation of 'beside' for more information.
 (|||) :: (Juxtaposable a, V a ~ R2, Semigroup a) => a -> a -> a
 (|||) = beside unitX
 
@@ -151,13 +154,13 @@ strutR2 v = phantom seg
   where
     seg = FLinear (origin .+^ 0.5 *^ v) (origin .+^ (-0.5) *^ v)
 
--- | @strutX d@ is an empty diagram with width @d@, height 0, and a
+-- | @strutX w@ is an empty diagram with width @w@, height 0, and a
 --   centered local origin.  Note that @strutX (-w)@ behaves the same as
 --   @strutX w@.
 strutX :: (Backend b R2, Monoid' m) => Double -> QDiagram b R2 m
 strutX d = strut (d & 0)
 
--- | @strutY d@ is an empty diagram with height @d@, width 0, and a
+-- | @strutY h@ is an empty diagram with height @h@, width 0, and a
 --   centered local origin. Note that @strutY (-h)@ behaves the same as
 --   @strutY h@.
 strutY :: (Backend b R2, Monoid' m) => Double -> QDiagram b R2 m
@@ -232,10 +235,10 @@ view p (coords -> w :& h) = withEnvelope (rect w h # alignBL # moveTo p :: D R2)
 
 -- | Construct a bounding rectangle for an enveloped object, that is,
 --   the smallest axis-aligned rectangle which encloses the object.
-boundingRect :: ( Enveloped p, Transformable p, PathLike p, V p ~ R2
+boundingRect :: ( Enveloped t, Transformable t, TrailLike t, Monoid t, V t ~ R2
                 , Enveloped a, V a ~ R2
                 )
-             => a -> p
+             => a -> t
 boundingRect = (`boxFit` rect 1 1) . boundingBox
 
 -- | \"Set the background color\" of a diagram.  That is, place a
