@@ -1,8 +1,7 @@
-{-# LANGUAGE FlexibleContexts
-           , TypeSynonymInstances
-           , MultiParamTypeClasses
-           , TypeFamilies
-  #-}
+{-# LANGUAGE FlexibleContexts      #-}
+{-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE TypeFamilies          #-}
+{-# LANGUAGE TypeSynonymInstances  #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Diagrams.TwoD.Ellipse
@@ -23,28 +22,29 @@ module Diagrams.TwoD.Ellipse
     , ellipseXY
     ) where
 
-import Diagrams.Core
+import           Diagrams.Core
 
-import Diagrams.TwoD.Types
-import Diagrams.TwoD.Transform
-import Diagrams.TwoD.Arc
-
-import Diagrams.Path
-import Diagrams.Util
+import           Diagrams.Located        (at)
+import           Diagrams.Path
+import           Diagrams.TrailLike
+import           Diagrams.TwoD.Arc
+import           Diagrams.TwoD.Transform
+import           Diagrams.TwoD.Types
+import           Diagrams.Util
 
 -- | A circle of radius 1, with center at the origin.
-unitCircle :: (PathLike p, V p ~ R2) => p
-unitCircle = pathLike (p2 (1,0)) True $ trailSegments (arcT 0 (tau::Rad))
+unitCircle :: (TrailLike t, V t ~ R2) => t
+unitCircle = trailLike $ arcT 0 (tau::Rad) `at` (p2 (1,0))
 
 -- | A circle of the given radius, centered at the origin.  As a path,
 --   it begins at (r,0).
-circle :: (PathLike p, V p ~ R2, Transformable p) => Double -> p
+circle :: (TrailLike t, V t ~ R2, Transformable t) => Double -> t
 circle d = unitCircle # scale d
 
 -- | @ellipse e@ constructs an ellipse with eccentricity @e@ by
 --   scaling the unit circle in the X direction.  The eccentricity must
 --   be within the interval [0,1).
-ellipse :: (PathLike p, V p ~ R2, Transformable p) => Double -> p
+ellipse :: (TrailLike t, V t ~ R2, Transformable t) => Double -> t
 ellipse e
     | e >= 0 && e < 1  = scaleX (sqrt (1 - e*e)) unitCircle
     | otherwise        = error "Eccentricity of ellipse must be >= 0 and < 1."
@@ -52,5 +52,5 @@ ellipse e
 -- | @ellipseXY x y@ creates an axis-aligned ellipse, centered at the
 --   origin, with radius @x@ along the x-axis and radius @y@ along the
 --   y-axis.
-ellipseXY :: (PathLike p, V p ~ R2, Transformable p) => Double -> Double -> p
+ellipseXY :: (TrailLike t, V t ~ R2, Transformable t) => Double -> Double -> t
 ellipseXY x y = unitCircle # scaleX x # scaleY y
