@@ -1,7 +1,5 @@
-{-# LANGUAGE TypeFamilies
-           , FlexibleContexts
-           , ViewPatterns
-  #-}
+{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE TypeFamilies     #-}
 
 -----------------------------------------------------------------------------
 -- |
@@ -22,6 +20,7 @@ module Diagrams.TwoD.Shapes
          -- * Regular polygons
 
        , regPoly
+       , triangle
        , eqTriangle
        , square
        , pentagon
@@ -44,44 +43,87 @@ module Diagrams.TwoD.Shapes
        , roundedRect'
        ) where
 
-import Diagrams.Core
+import           Diagrams.Core
 
-import Diagrams.Coordinates
-import Diagrams.Path
-import Diagrams.Segment
-import Diagrams.TwoD.Arc
-import Diagrams.TwoD.Polygons
-import Diagrams.TwoD.Transform
-import Diagrams.TwoD.Types
+import           Diagrams.Coordinates
+import           Diagrams.Located        (at)
+import           Diagrams.Path
+import           Diagrams.Segment
+import           Diagrams.Trail
+import           Diagrams.TrailLike
+import           Diagrams.TwoD.Arc
+import           Diagrams.TwoD.Polygons
+import           Diagrams.TwoD.Transform
+import           Diagrams.TwoD.Types
 
-import Diagrams.Util
+import           Diagrams.Util
 
-import Data.Default
-import Data.Semigroup
+import           Data.Default.Class
+import           Data.Semigroup
 
 -- | Create a centered horizontal (L-R) line of the given length.
-hrule :: (PathLike p, V p ~ R2) => Double -> p
-hrule d = pathLike (p2 (-d/2,0)) False [Linear (d & 0)]
+--
+--   <<diagrams/hruleEx.svg#diagram=hruleEx&width=300>>
+--
+--   > hruleEx = vcat' with {sep = 0.2} (map hrule [1..5])
+--   >         # centerXY # pad 1.1
+hrule :: (TrailLike t, V t ~ R2) => Double -> t
+hrule d = trailLike $ trailFromSegments [straight (d & 0)] `at` (p2 (-d/2,0))
 
 -- | Create a centered vertical (T-B) line of the given length.
-vrule :: (PathLike p, V p ~ R2) => Double -> p
-vrule d = pathLike (p2 (0,d/2)) False [Linear (0 & (-d))]
+--
+--   <<diagrams/vruleEx.svg#diagram=vruleEx&height=100>>
+--
+--   > vruleEx = hcat' with {sep = 0.2} (map vrule [1, 1.2 .. 2])
+--   >         # centerXY # pad 1.1
+vrule :: (TrailLike t, V t ~ R2) => Double -> t
+vrule d = trailLike $ trailFromSegments [straight (0 & (-d))] `at` (p2 (0,d/2))
 
 -- | A square with its center at the origin and sides of length 1,
 --   oriented parallel to the axes.
-unitSquare :: (PathLike p, V p ~ R2) => p
+--
+--   <<diagrams/unitSquareEx.svg#diagram=unitSquareEx&width=100>>
+unitSquare :: (TrailLike t, V t ~ R2) => t
 unitSquare = polygon with { polyType   = PolyRegular 4 (sqrt 2 / 2)
                           , polyOrient = OrientH }
 
+-- > unitSquareEx = unitSquare # pad 1.1 # showOrigin
+
 -- | A square with its center at the origin and sides of the given
 --   length, oriented parallel to the axes.
-square :: (PathLike p, Transformable p, V p ~ R2) => Double -> p
-square d = unitSquare # scale d
+--
+--   <<diagrams/squareEx.svg#diagram=squareEx&width=200>>
+square :: (TrailLike t, Transformable t, V t ~ R2) => Double -> t
+square d = rect d d
+
+-- > squareEx = hcat' with {sep = 0.5} [square 1, square 2, square 3]
+-- >          # centerXY # pad 1.1 # lw 0.03
 
 -- | @rect w h@ is an axis-aligned rectangle of width @w@ and height
 --   @h@, centered at the origin.
-rect :: (PathLike p, Transformable p, V p ~ R2) => Double -> Double -> p
-rect w h = unitSquare # scaleX w # scaleY h
+--
+--   <<diagrams/rectEx.svg#diagram=rectEx&width=150>>
+rect :: (TrailLike t, Transformable t, V t ~ R2) => Double -> Double -> t
+rect w h = trailLike . head . pathTrails $ unitSquare # scaleX w # scaleY h
+
+-- > rectEx = rect 1 0.7 # pad 1.1
+
+    -- The above may seem a bit roundabout.  In fact, we used to have
+    --
+    --   rect w h = unitSquare # scaleX w # scaleY h
+    --
+    -- since unitSquare can produce any TrailLike.  The current code
+    -- instead uses (unitSquare # scaleX w # scaleY h) to specifically
+    -- produce a Path, which is then deconstructed and passed back into
+    -- 'trailLike' to create any TrailLike.
+    --
+    -- The difference is that while scaling by zero works fine for
+    -- Path it does not work very well for, say, Diagrams (leading to
+    -- NaNs or worse).  This way, we force the scaling to happen on a
+    -- Path, where we know it will behave properly, and then use the
+    -- resulting geometry to construct an arbitrary TrailLike.
+    --
+    -- See https://github.com/diagrams/diagrams-lib/issues/43 .
 
 ------------------------------------------------------------
 --  Regular polygons
@@ -93,57 +135,90 @@ rect w h = unitSquare # scaleX w # scaleY h
 --   polygons of a given /radius/).
 --
 --   The polygon will be oriented with one edge parallel to the x-axis.
-regPoly :: (PathLike p, V p ~ R2) => Int -> Double -> p
+regPoly :: (TrailLike t, V t ~ R2) => Int -> Double -> t
 regPoly n l = polygon with { polyType =
                                PolySides
-                                 (repeat (1/ fromIntegral n :: CircleFrac))
+                                 (repeat (1/ fromIntegral n :: Turn))
                                  (replicate (n-1) l)
                            , polyOrient = OrientH
                            }
 
--- | An equilateral triangle, with sides of the given length and base parallel
---   to the x-axis.
-eqTriangle :: (PathLike p, V p ~ R2) => Double -> p
-eqTriangle = regPoly 3
+-- > shapeEx sh   = sh 1 # pad 1.1
+-- > triangleEx   = shapeEx triangle
+-- > pentagonEx   = shapeEx pentagon
+-- > hexagonEx    = shapeEx hexagon
+-- > septagonEx   = shapeEx septagon
+-- > octagonEx    = shapeEx octagon
+-- > nonagonEx    = shapeEx nonagon
+-- > decagonEx    = shapeEx decagon
+-- > hendecagonEx = shapeEx hendecagon
+-- > dodecagonEx  = shapeEx dodecagon
+
+-- | A synonym for 'triangle', provided for backwards compatibility.
+eqTriangle :: (TrailLike t, V t ~ R2) => Double -> t
+eqTriangle = triangle
+
+-- | An equilateral triangle, with sides of the given length and base
+--   parallel to the x-axis.
+--
+--   <<diagrams/triangleEx.svg#diagram=triangleEx&width=100>>
+triangle :: (TrailLike t, V t ~ R2) => Double -> t
+triangle = regPoly 3
 
 -- | A regular pentagon, with sides of the given length and base
 --   parallel to the x-axis.
-pentagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/pentagonEx.svg#diagram=pentagonEx&width=100>>
+pentagon :: (TrailLike t, V t ~ R2) => Double -> t
 pentagon = regPoly 5
 
 -- | A regular hexagon, with sides of the given length and base
 --   parallel to the x-axis.
-hexagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/hexagonEx.svg#diagram=hexagonEx&width=100>>
+hexagon :: (TrailLike t, V t ~ R2) => Double -> t
 hexagon = regPoly 6
 
 -- | A regular septagon, with sides of the given length and base
 --   parallel to the x-axis.
-septagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/septagonEx.svg#diagram=septagonEx&width=100>>
+septagon :: (TrailLike t, V t ~ R2) => Double -> t
 septagon = regPoly 7
 
 -- | A regular octagon, with sides of the given length and base
 --   parallel to the x-axis.
-octagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/octagonEx.svg#diagram=octagonEx&width=100>>
+octagon :: (TrailLike t, V t ~ R2) => Double -> t
 octagon = regPoly 8
 
 -- | A regular nonagon, with sides of the given length and base
 --   parallel to the x-axis.
-nonagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/nonagonEx.svg#diagram=nonagonEx&width=100>>
+nonagon :: (TrailLike t, V t ~ R2) => Double -> t
 nonagon = regPoly 9
 
 -- | A regular decagon, with sides of the given length and base
 --   parallel to the x-axis.
-decagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/decagonEx.svg#diagram=decagonEx&width=100>>
+decagon :: (TrailLike t, V t ~ R2) => Double -> t
 decagon = regPoly 10
 
 -- | A regular hendecagon, with sides of the given length and base
 --   parallel to the x-axis.
-hendecagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/hendecagonEx.svg#diagram=hendecagonEx&width=100>>
+hendecagon :: (TrailLike t, V t ~ R2) => Double -> t
 hendecagon = regPoly 11
 
 -- | A regular dodecagon, with sides of the given length and base
 --   parallel to the x-axis.
-dodecagon :: (PathLike p, V p ~ R2) => Double -> p
+--
+--   <<diagrams/dodecagonEx.svg#diagram=dodecagonEx&width=100>>
+dodecagon :: (TrailLike t, V t ~ R2) => Double -> t
 dodecagon = regPoly 12
 
 ------------------------------------------------------------
@@ -159,8 +234,19 @@ dodecagon = regPoly 12
 --   the corners from overlapping.  The trail or path begins with the
 --   right edge and proceeds counterclockwise.  If you need to specify
 --   a different radius for each corner individually, use
---   @roundedRect'@ instead.
-roundedRect :: (PathLike p, V p ~ R2) => Double -> Double -> Double -> p
+--   'roundedRect'' instead.
+--
+--   <<diagrams/roundedRectEx.svg#diagram=roundedRectEx&width=400>>
+--
+--   > roundedRectEx = pad 1.1 . centerXY $ hcat' with { sep = 0.2 }
+--   >   [ roundedRect  0.5 0.4 0.1
+--   >   , roundedRect  0.5 0.4 (-0.1)
+--   >   , roundedRect' 0.7 0.4 with { radiusTL = 0.2
+--   >                               , radiusTR = -0.2
+--   >                               , radiusBR = 0.1 }
+--   >   ]
+
+roundedRect :: (TrailLike t, V t ~ R2) => Double -> Double -> Double -> t
 roundedRect w h r = roundedRect' w h (with { radiusTL = r,
                                              radiusBR = r,
                                              radiusTR = r,
@@ -170,10 +256,12 @@ roundedRect w h r = roundedRect' w h (with { radiusTL = r,
 --   each corner indivually, using @RoundedRectOpts@. The default corner radius is 0.
 --   Each radius can also be negative, which results in the curves being reversed
 --   to be inward instead of outward.
-roundedRect' :: (PathLike p, V p ~ R2) => Double -> Double -> RoundedRectOpts -> p
+roundedRect' :: (TrailLike t, V t ~ R2) => Double -> Double -> RoundedRectOpts -> t
 roundedRect' w h opts
-   = pathLike (p2 (w/2, abs rBR - h/2)) True
-   . trailSegments
+   = trailLike
+   . (`at` (p2 (w/2, abs rBR - h/2)))
+   . wrapTrail
+   . glueLine
    $ seg (0, h - abs rTR - abs rBR)
    <> mkCorner 0 rTR
    <> seg (abs rTR + abs rTL - w, 0)
@@ -182,7 +270,7 @@ roundedRect' w h opts
    <> mkCorner 2 rBL
    <> seg (w - abs rBL - abs rBR, 0)
    <> mkCorner 3 rBR
-  where seg   = fromOffsets . (:[]) . r2
+  where seg   = lineFromOffsets . (:[]) . r2
         diag  = sqrt (w * w + h * h)
         -- to clamp corner radius, need to compare with other corners that share an
         -- edge. If the corners overlap then reduce the largest corner first, as far
@@ -205,7 +293,7 @@ roundedRect' w h opts
         mkCorner k r | r == 0    = mempty
                      | r < 0     = doArc 3 2
                      | otherwise = doArc 0 1
-                     where doArc d d' = arc' r ((k+d)/4) ((k+d')/4:: CircleFrac)
+                     where doArc d d' = arc' r ((k+d)/4) ((k+d')/4:: Turn)
 
 data RoundedRectOpts = RoundedRectOpts { radiusTL :: Double
                                        , radiusTR :: Double
