@@ -24,7 +24,7 @@ module Diagrams.TwoD.Text (
   -- ** Font family
   , Font(..), getFont, font
   -- ** Font size
-  , FontSize(..), getFontSize, fontSize
+  , FontSize(..), getFontSize, fontSize, fontSizeA
   -- ** Font slant
   , FontSlant(..), FontSlantA, getFontSlant, fontSlant, italic, oblique
   -- ** Font weight
@@ -41,7 +41,9 @@ import Data.Semigroup
 
 import Data.Colour
 
-import Data.Typeable
+import           Data.Default.Class
+
+import           Data.Typeable
 
 ------------------------------------------------------------
 -- Text diagrams
@@ -58,6 +60,8 @@ type instance V Text = R2
 instance Transformable Text where
   transform t (Text tt a s) = Text (t <> tt) a s
 
+instance IsPrim Text
+
 instance HasOrigin Text where
   moveOriginTo p = translate (origin .-. p)
 
@@ -68,13 +72,35 @@ instance Renderable Text NullBackend where
 data TextAlignment = BaselineText | BoxAlignedText Double Double
 
 mkText :: Renderable Text b => TextAlignment -> String -> Diagram b R2
-mkText a t = recommendFillColor black
+mkText a t = recommendFillColor black   -- See Note [recommendFillColor]
            $ mkQD (Prim (Text mempty a t))
                        mempty
                        mempty
                        mempty
                        mempty
 
+-- ~~~~ Note [recommendFillColor]
+
+-- The reason we "recommend" a fill color of black instead of setting
+-- it directly (or instead of simply not specifying a fill color at
+-- all) was originally to support the SVG backend, though it is
+-- actually in some sense the "right thing" to do, and other backends
+-- we add later may conceivably need it as well.  The cairo backend
+-- defaults happen to be to use a transparent fill for paths and a
+-- black fill for text.  The SVG standard, however, specifies a
+-- default fill of black for everything (both text and paths).  In
+-- order to correctly render paths with no fill set, the SVG backend
+-- must therefore explicitly set the fill to transparent -- but this
+-- meant that it was also drawing text with a transparent fill.  The
+-- solution is that we now explicitly inform all backends that the
+-- *default* ("recommended") fill color for text should be black; an
+-- absence of fill specification now consistently means to use a
+-- "transparent" fill no matter what the primitive.  The reason we
+-- need the special recommend/commit distinction is because if the
+-- user explicitly sets a fill color later it should override this
+-- recommendation; normally, the innermost occurrence of an attribute
+-- would override all outer occurrences.
+
 -- | Create a primitive text diagram from the given string, with center
 --   alignment, equivalent to @'alignedText' 0.5 0.5@.
 --
@@ -143,6 +169,9 @@ newtype FontSize = FontSize (Last Double)
   deriving (Typeable, Semigroup, Eq)
 instance AttributeClass FontSize
 
+instance Default FontSize where
+    def = FontSize (Last 1)
+
 -- | Extract the size from a @FontSize@ attribute.
 getFontSize :: FontSize -> Double
 getFontSize (FontSize (Last s)) = s
@@ -153,6 +182,10 @@ getFontSize (FontSize (Last s)) = s
 fontSize :: HasStyle a => Double -> a -> a
 fontSize = applyAttr . FontSize . Last
 
+-- | Apply a 'FontSize' attribute.
+fontSizeA :: HasStyle a => FontSize -> a -> a
+fontSizeA = applyAttr
+
 --------------------------------------------------
 -- Font slant
 
