@@ -1,8 +1,8 @@
-{-# LANGUAGE FlexibleContexts
-           , FlexibleInstances
-           , TypeFamilies
-           , ViewPatterns
-  #-}
+{-# LANGUAGE FlexibleContexts      #-}
+{-# LANGUAGE FlexibleInstances     #-}
+{-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE TypeFamilies          #-}
+{-# LANGUAGE ViewPatterns          #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Diagrams.TwoD.Transform
@@ -46,25 +46,28 @@ module Diagrams.TwoD.Transform
        , shearingY, shearY
 
          -- * Scale invariance
-       , ScaleInv(..), scaleInv
+       , ScaleInv(..), scaleInv, scaleInvPrim
 
+         -- * component-wise
+       , onBasis
        ) where
 
-import Diagrams.Core
+import           Diagrams.Core
+import qualified Diagrams.Core.Transform as T
 
-import Control.Newtype (over)
+import           Control.Newtype         (over)
 
-import Diagrams.Coordinates
-import Diagrams.Transform
-import Diagrams.TwoD.Size   (width, height)
-import Diagrams.TwoD.Types
-import Diagrams.TwoD.Vector (direction)
+import           Diagrams.Coordinates
+import           Diagrams.Transform
+import           Diagrams.TwoD.Size      (height, width)
+import           Diagrams.TwoD.Types
+import           Diagrams.TwoD.Vector    (direction)
 
-import Data.Semigroup
+import           Data.Semigroup
 
-import Data.AffineSpace
+import           Data.AffineSpace
 
-import Control.Arrow (first, second)
+import           Control.Arrow           (first, second)
 
 -- Rotation ------------------------------------------------
 
@@ -81,7 +84,7 @@ rotation ang = fromLinear r (linv r)
 --   correspond to counterclockwise rotation, negative to
 --   clockwise. The angle can be expressed using any type which is an
 --   instance of 'Angle'.  For example, @rotate (1\/4 ::
---   'CircleFrac')@, @rotate (tau\/4 :: 'Rad')@, and @rotate (90 ::
+--   'Turn')@, @rotate (tau\/4 :: 'Rad')@, and @rotate (90 ::
 --   'Deg')@ all represent the same transformation, namely, a
 --   counterclockwise rotation by a right angle.  To rotate about some
 --   point other than the local origin, see 'rotateAbout'.
@@ -89,14 +92,14 @@ rotation ang = fromLinear r (linv r)
 --   Note that writing @rotate (1\/4)@, with no type annotation, will
 --   yield an error since GHC cannot figure out which sort of angle
 --   you want to use.  In this common situation you can use
---   'rotateBy', which is specialized to take a 'CircleFrac' argument.
+--   'rotateBy', which is specialized to take a 'Turn' argument.
 rotate :: (Transformable t, V t ~ R2, Angle a) => a -> t -> t
 rotate = transform . rotation
 
 -- | A synonym for 'rotate', specialized to only work with
---   @CircleFrac@ arguments; it can be more convenient to write
---   @rotateBy (1\/4)@ than @'rotate' (1\/4 :: 'CircleFrac')@.
-rotateBy :: (Transformable t, V t ~ R2) => CircleFrac -> t -> t
+--   @Turn@ arguments; it can be more convenient to write
+--   @rotateBy (1\/4)@ than @'rotate' (1\/4 :: 'Turn')@.
+rotateBy :: (Transformable t, V t ~ R2) => Turn -> t -> t
 rotateBy = transform . rotation
 
 -- | @rotationAbout p@ is a rotation about the point @p@ (instead of
@@ -248,9 +251,6 @@ shearY = transform . shearingY
 
 -- Scale invariance ----------------------------------------
 
--- XXX what about freezing?  Doesn't interact with ScaleInv the way it
--- ought.
-
 -- | The @ScaleInv@ wrapper creates two-dimensional /scale-invariant/
 --   objects.  Intuitively, a scale-invariant object is affected by
 --   transformations like translations and rotations, but not by scales.
@@ -284,13 +284,14 @@ shearY = transform . shearingY
 
 data ScaleInv t =
   ScaleInv
-  { unScaleInv :: t
+  { unScaleInv  :: t
   , scaleInvDir :: R2
   , scaleInvLoc :: P2
   }
   deriving (Show)
 
--- | Create a scale-invariant object pointing in the given direction.
+-- | Create a scale-invariant object pointing in the given direction,
+--   located at the origin.
 scaleInv :: t -> R2 -> ScaleInv t
 scaleInv t d = ScaleInv t d origin
 
@@ -304,7 +305,54 @@ instance (V t ~ R2, Transformable t) => Transformable (ScaleInv t) where
     where
       angle :: Rad
       angle = direction (transform tr v) - direction v
-      rot :: ( Transformable t,  (V t ~ R2) ) => t -> t
+      rot :: (Transformable t, V t ~ R2) => t -> t
       rot = rotateAbout l angle
       l'  = transform tr l
       trans = translate (l' .-. l)
+
+-- This is how we handle freezing properly with ScaleInv wrappers.
+-- Normal transformations are applied ignoring scaling; "frozen"
+-- transformations (i.e. transformations applied after a freeze) are
+-- applied directly to the underlying object, scales and all.  We must
+-- take care to transform the reference point and direction vector
+-- appropriately.
+instance (V t ~ R2, Transformable t) => IsPrim (ScaleInv t) where
+  transformWithFreeze t1 t2 s = ScaleInv t'' d'' origin''
+    where
+      -- first, apply t2 normally, i.e. ignoring scaling
+      s'@(ScaleInv t' _ _)      = transform t2 s
+
+      -- now apply t1 to get the new direction and origin
+      (ScaleInv _ d'' origin'') = transform t1 s'
+
+      -- but apply t1 directly to the underlying thing, scales and all.
+      t''                       = transform t1 t'
+
+instance (Renderable t b, V t ~ R2) => Renderable (ScaleInv t) b where
+  render b = render b . unScaleInv
+
+-- | Create a diagram from a single scale-invariant primitive.  The
+--   vector argument specifies the direction in which the primitive is
+--   \"pointing\" (for the purpose of keeping it rotated correctly
+--   under non-uniform scaling).  The primitive is assumed to be
+--   \"located\" at the origin (for the purpose of translating it
+--   correctly under scaling).
+--
+--   Note that the resulting diagram will have an /empty/ envelope,
+--   trace, and query.  The reason is that the envelope, trace, and
+--   query cannot be cached---applying a transformation would cause
+--   the cached envelope, etc. to get \"out of sync\" with the
+--   scale-invariant object.  The intention, at any rate, is that
+--   scale-invariant things will be used only as \"decorations\" (/e.g./
+--   arrowheads) which should not affect the envelope, trace, and
+--   query.
+scaleInvPrim :: (Transformable t, Renderable t b, V t ~ R2, Monoid m)
+             => t -> R2 -> QDiagram b R2 m
+scaleInvPrim t d = mkQD (Prim $ scaleInv t d) mempty mempty mempty mempty
+
+-- | Get the matrix equivalent of the linear transform,
+--   (as a pair of columns) and the translation vector.  This
+--   is mostly useful for implementing backends.
+onBasis :: Transformation R2 -> ((R2, R2), R2)
+onBasis t = ((x, y), v)
+  where ((x:y:[]), v) = T.onBasis t
